Cleaner
=======

.. currentmodule:: pykeen.triples.splitting

.. autoclass:: Cleaner
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Cleaner.__call__
      ~Cleaner.cleanup_pair

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: cleanup_pair
